# UFT 2.0.6 

UFT (Universal File Transfer) is a CLI tool , which can  be used to upload files to a public server and any one can download it...
<p float="left">
 <img src="https://komarev.com/ghpvc/?username=merwin-UFT&label=Project%20views&color=0e75b6&style=flat" alt="darkmash-org" /> 
<img alt="" src="https://static.pepy.tech/personalized-badge/uft?period=total&units=international_system&left_color=blue&right_color=orange&left_text=Downloads">

</p>
### Status
  - https://raw.githubusercontent.com/darkmash-org/UFT/main/status.txt

## Features

- Encrytion (RSA)
- Easy to use
- INSTALLER ( for linux )

## Up Commings - v3
- SPV(secure password varification) 
- File compression 
- E2EE
- Relays 
- Decentralised 

## Installation :

### Using Pip:

```
  pip install uft # or pip3 install uft (on linux)
```

### Linux:

```
git clone https://github.com/mastercodermerwin/UFT.git
```

```
cd UFT
```

```
sudo python3 installer.py # or python installer.py
```

### On Other OS`s
Use without adding to path..

```
git clone https://github.com/mastercodermerwin/UFT.git
```

```
cd UFT
```

```
python main.py
```


## How To Use:

```
user> uft help
```
Get help how to use UFT.

```
user> =uft upload (filename) (password)
```
Upload a file.

```
user> uft download (filename) (output) 
```
Download a file.

```
user> uft delete (filename) (password) 
```
Delete a file.

```
user> uft replace (filename) (newfile) (password)
``` 
Replace a file.

<hr>

## Testing
       
<p align="center">
<img src="https://cdn.discordapp.com/attachments/951417646191083551/1077843592057454653/Screenshot_from_2023-02-22_12-09-32.png">
  </p>
<p align="center">
<img width="45%" src="https://cdn.discordapp.com/attachments/951417646191083551/1077843622327758848/Screenshot_from_2023-02-22_12-10-48.png">
<img  width="45%" src="https://cdn.discordapp.com/attachments/951417646191083551/1077843652967137320/Screenshot_from_2023-02-22_12-11-21.png">
</p>
<p align="center">

  <img src="https://cdn.discordapp.com/attachments/951417646191083551/1077843704838115348/Screenshot_from_2023-02-22_12-11-57.png">
</p>

<hr>

## License

[MIT](https://choosealicense.com/licenses/mit/)


## Authors

- [@Merwin](https://www.github.com/mastercodermerwin)


 

<hr>
<details>
    <summary><b>✨Discord Server & Support</b></summary><br/>
 <h3 align="center">Darkmash Official Server </h3>
 
### ⬇️ ⬇️ ⬇️ ⬇️ INVITE LINK ⬇️ ⬇️ ⬇️ ⬇️ 

https://discord.gg/SC54bSgnyQ
</details>  
